@@ -11,10 +11,6 @@ class BaseCallbacks(object):
 
     __slots__ = ()
 
-
-    def on_init(self):
-        pass
-
     def on_scene_start(self, scene):
         pass
 
@@ -36,15 +32,14 @@ class BaseCallbacks(object):
     def keyboard_interrupt(self):
         pass
 
+    def on_multiplayer_advance(self):
+        pass
+
 
 class DefaultCallbacks(BaseCallbacks):
 
     __slots__ = ()
 
-
-    def on_init(self):
-        super(DefaultCallback).__init__()
-
     def on_scene_start(self, scene):
         print("> starting scene: %s (%s)" % (scene.name, scene.obj_id))
 
@@ -71,9 +66,6 @@ class DefaultCallbacks(BaseCallbacks):
         print("> keyboard interrupt")
         pass
 
-class WebCallbacks(object):
-    pass
-
 class Callbacks(object):
 
     __slots__ = ()
@@ -118,6 +110,11 @@ class Callbacks(object):
         for cb in Callbacks.CALLBACKS:
             cb.all_clips_done()
 
+    @classmethod
+    def on_multiplayer_advance(cls):
+        for cb in Callbacks.CALLBACKS:
+            cb.on_multiplayer_advance()
+
     @classmethod
     def keyboard_interrupt(cls):
         for cb in Callbacks.CALLBACKS:
