@@ -21,6 +21,6 @@ class DataPools(CollectionApi):
         params = locals()
         return self._generic_add(name, params)
 
-    def edit(self, name, new_name:str=None, slots:list=None, direction=None, length=None):
+    def edit(self, name, id:str=None, new_name:str=None, slots:list=None, direction=None, length=None):
         params = locals()
         return self._generic_edit(name, params)
\ No newline at end of file
