@@ -24,7 +24,7 @@ class Patterns(CollectionApi):
         params = locals()
         return self._generic_add(name, params)
 
-    def edit(self, name, new_name:str=None, slots:list=None, scale=None, octave_shift=None, rate=None,  direction=None, length=None):
+    def edit(self, name, id:str=None, new_name:str=None, slots:list=None, scale=None, octave_shift=None, rate=None,  direction=None, length=None):
         if scale:
             scale = self.api.scales.lookup(scale, require=True)
         params = locals()
