@@ -24,7 +24,7 @@ class Scenes(CollectionApi):
         params = locals()
         return self._generic_add(name, params)
 
-    def edit(self, name, new_name:str=None, scale:str=None, auto_advance:bool=None, rate:int=None):
+    def edit(self, name, id:str=None, new_name:str=None, scale:str=None, auto_advance:bool=None, rate:int=None):
         if scale:
             scale = self.api.scales.lookup(scale, require=True)
         params = locals()
