@@ -19,7 +19,7 @@ class Tracks(CollectionApi):
     nullable_edits  = [ ]
 
     def add(self, name, instrument:str=None, instruments:list=None, instrument_mode:str=None, muted:bool=False):
-        if not (instrument or instruments):
+        if not (instrument or (instruments is not None)):
             raise InvalidUsage("either instrument or instruments is required")
         if instruments is None:
             instruments = []
@@ -28,7 +28,7 @@ class Tracks(CollectionApi):
             instrument = self.api.instruments.lookup(instrument, require=True)
         return self._generic_add(name, locals())
 
-    def edit(self, name, new_name:str=None, instrument:str=None, instruments:list=None, instrument_mode:str=None, muted:bool=False):
+    def edit(self, name, id:str=None, new_name:str=None, instrument:str=None, instruments:list=None, instrument_mode:str=None, muted:bool=False):
         if instrument:
             instrument = self.api.instruments.lookup(instrument, require=True)
         if instruments is not None:
