@@ -22,6 +22,6 @@ class Transforms(CollectionApi):
         params = locals()
         return self._generic_add(name, params)
 
-    def edit(self, name, new_name:str=None, slots:list=None, divide:int=1, applies_to:str=None, direction=None, auto_reset=None):
+    def edit(self, name, id:str=None, new_name:str=None, slots:list=None, divide:int=1, applies_to:str=None, direction=None, auto_reset=None):
         params = locals()
         return self._generic_edit(name, params)
\ No newline at end of file
