@@ -25,14 +25,15 @@ class NewReferenceObject(BaseObject):
 
     __slots__ = ( 'obj_id' )
 
-    def new_object_id(self):
+    @classmethod
+    def new_object_id(cls):
         global COUNTER
         COUNTER = COUNTER + 1
         return str(COUNTER)
 
     def __init__(self):
         if self.obj_id in [ None, '0' ]:
-            self.obj_id = self.new_object_id()
+            self.obj_id = NewReferenceObject.new_object_id()
 
     def to_dict(self):
         return save_object(self)
