@@ -4,13 +4,6 @@
 # Apache2 Licensed
 # ------------------------------------------------------------------
 
-from ..api.exceptions import *
-from .base import BaseObject
-from .note import Note
-from .pattern import Pattern
-from .scale import Scale
-from .transform import Transform
-
 # https://en.wikipedia.org/wiki/Chord_names_and_symbols_(popular_music)
 # minor 2nd - 2 semitones
 # minor 3rd - 3 semitones
@@ -152,5 +145,17 @@ class Chord(object):
     def get_notes(self):
         return self.notes
 
+    def record_octave_set(self, value):
+        for x in self.notes:
+            note.record_octave_set(value)
+
+    def record_octave_shift(self, value):
+        for x in self.notes:
+            note.record_octave_shift(value)
+
+    def record_degree_shift(self, value):
+        for x in self.notes:
+            note.record_degree_set(value)
+
     def __repr__(self):
-        return "Chord [%s]" % (",".join(str(x) for x in self.notes))
+        return "Chord <%s>" % (",".join(str(x) for x in self.notes))
