@@ -8,6 +8,7 @@
 
 from .base import NewReferenceObject
 from warpseq.playback.midi import open_port
+from warpseq.playback.midi import midi_note_on, midi_note_off, midi_cc
 
 class Device(NewReferenceObject):
 
@@ -25,3 +26,12 @@ class Device(NewReferenceObject):
         if self._midi_out is None:
             self._midi_out = open_port(self.name)
         return self._midi_out
+
+    def midi_note_on(self, channel, note_number, velocity):
+        midi_note_on(self.get_midi_out(), channel, note_number, velocity)
+
+    def midi_note_off(self, channel, note_number, velocity):
+        midi_note_off(self.get_midi_out(), channel, note_number, velocity)
+
+    def midi_cc(self, channel, controller, value):
+        midi_cc(self.get_midi_out(), channel, controller, value)
