@@ -20,7 +20,11 @@ class Instrument(NewReferenceObject):
                  default_velocity=120, muted=False, obj_id=None):
 
         self.name = name
-        self.channel = int(channel)
+
+        if channel is not None:
+            channel = int(channel)
+
+        self.channel = channel
         self.device = device
         self.min_octave = min_octave
         self.base_octave = base_octave
