@@ -31,6 +31,8 @@ SCALE_DEGREES_TO_STEPS = {
    '8'  : 6
 }
 
+SCALE_DEGREES_FOR_UI = [x for x in  SCALE_DEGREES_TO_STEPS.keys() if x != '0' ]
+
 class Note(object):
 
     __slots__ = ( 'name', 'octave', 'tie', 'length', 'start_time', 'end_time', 'velocity', 'from_scale',
@@ -124,10 +126,18 @@ class Note(object):
         return Chord(root=self, chord_type=chord_type, from_scale=self.from_scale)
 
     def scale_transpose(self, scale_obj, steps):
+
         snn = self.note_number()
         scale_notes = scale_obj.get_notes()
         note_numbers = scale_obj.get_note_numbers()
-        scale_note = scale_notes[utils.index_where_exceeds(note_numbers, snn) + steps]
+
+        new_index = utils.index_where_exceeds(note_numbers, snn) + steps
+
+        if new_index < 0:
+            correct_octaves = (int(new_index / 12) * -1) + 1
+            return self.transpose(octaves=correct_octaves).scale_transpose(scale_obj, steps).transpose(octaves=-correct_octaves)
+
+        scale_note = scale_notes[new_index ]
         n1 = self
         n1.name = scale_note.name
         n1.octave = scale_note.octave
