@@ -10,7 +10,7 @@ from .base import NewReferenceObject
 
 class Scene(NewReferenceObject):
 
-    __slots__ = ('name', 'scale', 'auto_advance', 'rate', '_clip_ids', 'obj_id' )
+    __slots__ = ('name', 'scale', 'auto_advance', 'rate', 'clip_ids', 'obj_id' )
 
     SAVE_AS_REFERENCES = [ 'scale', ]
 
@@ -20,26 +20,26 @@ class Scene(NewReferenceObject):
         self.scale = scale
         self.auto_advance = auto_advance
         self.rate = rate
-        self._clip_ids = clip_ids
+        self.clip_ids = clip_ids
         self.obj_id = obj_id
 
-        if self._clip_ids is None:
-            self._clip_ids = []
+        if self.clip_ids is None:
+            self.clip_ids = []
 
         super(Scene, self).__init__()
 
     def clips(self, song):
-        results = [ song.find_clip(x) for x in self._clip_ids ]
+        results = [ song.find_clip(x) for x in self.clip_ids ]
         results = [ r for r in results if r is not None ]
         return results
 
     def add_clip(self, clip):
-        if clip.obj_id not in self._clip_ids:
-            self._clip_ids.append(clip.obj_id)
+        if clip.obj_id not in self.clip_ids:
+            self.clip_ids.append(clip.obj_id)
 
     def has_clip(self, clip):
-        return clip.obj_id in self._clip_ids
+        return clip.obj_id in self.clip_ids
 
     def remove_clip(self, clip):
-        self.clip_ids = [ c for c in self._clip_ids if c != clip.obj_id ]
+        self.clip_ids = [ c for c in self.clip_ids if c != clip.obj_id ]
 
