@@ -27,10 +27,7 @@ class Deferrable(object):
         self.function = function
 
     def evaluate(self, track, note):
-        print("FN=%s" % self.function)
-        print("HOW=%s" % self.how)
         result = self.function(context=self.context, track=track, subject=note, how=self.how)
-        print("DEFERRABLE: %s" % result)
         return result
 
 class BaseSlot(object):
@@ -123,6 +120,8 @@ class Slot(BaseSlot):
 
         # FIXME: rename 'note' to 'obj'
 
+        #print("-------")
+
         note = self._standardize_input(note).copy()
 
         if note.length is None:
@@ -166,11 +165,14 @@ class Slot(BaseSlot):
             assert note.length is not None
 
         if self.degree:
-            note = note.scale_transpose(context.scale, evaluate(context=context, subject=note, how=self.degree) -1 )
+            res = evaluate(context=context, subject=note, how=self.degree) - 1
+            # print("debug: set scale scale degree: %s" % res)
+            note = note.scale_transpose(context.scale,  res)
 
         if self.octave is not None:
             res = evaluate(context=context, subject=note, how=self.octave)
             note = note.with_octave(res)
+            #print("debug: set octave=%s" % res)
             note.record_octave_set(res)
 
         # -----
@@ -179,11 +181,13 @@ class Slot(BaseSlot):
         if self.octave_shift is not None:
             how = evaluate(context=context, subject=note, how=self.octave_shift)
             note = note.transpose(octaves=how)
+            #print("octave transpose: %s" % how)
             note.record_octave_shift(how)
 
         if self.degree_shift is not None:
             how = evaluate(context=context, subject=note, how=self.degree_shift)
             note = note.scale_transpose(context.scale, how)
+            #print("degree shift: %s" % how)
             note.record_degree_shift(how)
 
         if self.repeats:
@@ -239,6 +243,7 @@ class Slot(BaseSlot):
 # ======================================================================================================================
 
 def defer_track_grab(context=None, track=None, subject=None, how=None):
+
     other_track = context.song.find_track_by_name(how)
 
     playing = get_first_playing_note(other_track.name)
@@ -246,12 +251,12 @@ def defer_track_grab(context=None, track=None, subject=None, how=None):
         return None
     copy_tracks = playing.track_copy
     if copy_tracks and track not in copy_tracks:
+        #print("on track (%s), this was not for me" % (track.name))
         return None
 
     new_note = subject.replace_with_note(playing.name, playing.octave)
 
     if new_note is None:
-        print("** DEFERRED GRAB MISS **")
         return None
 
     first = subject
@@ -263,7 +268,7 @@ def defer_track_grab(context=None, track=None, subject=None, how=None):
     if playing.from_scale:
         new_note = subject.scale_transpose(playing.from_scale, first.degree_shifts_recorded)
 
-    print("** GRABBED: %s" % new_note)
+    #print("on track (%s), grabbed (%s)" % (track.name, new_note))
     return new_note
 
 
