@@ -9,6 +9,7 @@
 
 from .base import NewReferenceObject
 from .instrument import Instrument
+from warpseq.utils import utils
 
 ALL_INSTRUMENTS = 'all_instruments'
 ROTATE = 'rotate'
@@ -18,7 +19,7 @@ INSTRUMENT_MODE_CHOICES = [ ALL_INSTRUMENTS, ROTATE, ROTATE_CHORDS, SPREAD ]
 
 class Track(NewReferenceObject):
 
-    __slots__ = [ 'name', 'muted', 'instruments', 'clip_ids', 'obj_id', 'instrument_mode' ]
+    __slots__ = [ 'name', 'muted', 'instruments', 'clip_ids', 'obj_id', 'instrument_mode', '_all_instruments', '_hocket_roller' ]
 
     SAVE_AS_REFERENCES = [ 'instruments' ]
 
@@ -46,11 +47,34 @@ class Track(NewReferenceObject):
             clip_ids = []
         self.clip_ids = clip_ids
 
+        self._hocket_roller = utils.roller(self.instruments)
+
         super(Track, self).__init__()
 
 
-    def get_instruments_to_play(self):
-        return self.instruments
+    # ------------------------------------------------------------------------------------------------------------------
+
+    def get_instruments(self, evt, chosen, instrument_mode):
+        if instrument_mode == ALL_INSTRUMENTS:
+            return self.instruments
+        elif instrument_mode in [ROTATE_CHORDS, SPREAD]:
+            return [next(self._hocket_roller)]
+        elif instrument_mode == ROTATE:
+            return [chosen]
+        else:
+            raise Exception("unknown mode")
+
+    # ------------------------------------------------------------------------------------------------------------------
+
+    def before_instrument_select(self, instrument_mode):
+
+        if instrument_mode == SPREAD:
+            self._hocket_roller = utils.roller(self.instruments)
+        if instrument_mode == ROTATE:
+            return next(self._hocket_roller)
+        return None
+
+    # ------------------------------------------------------------------------------------------------------------------
 
     def has_clip(self, clip):
         return clip.obj_id in self.clip_ids
