@@ -22,8 +22,9 @@ APPLIES_CHOICES = [ CHORDS, NOTES, BOTH ]
 class Transform(NewReferenceObject, Directionable):
 
     __slots__ = [ 'name', 'slots', '_current_slots', 'divide', 'applies_to', 'obj_id',
-                  'direction', '_current_direction', '_iterator', '_mod', '_slot_mods', 'auto_reset' ]
+                  'direction', '_current_direction', '_iterator', '_slot_mods', 'auto_reset' ]
 
+    SAVE_AS_REFERENCES = [ ]
 
     # ==================================================================================================================
 
