@@ -37,13 +37,13 @@ class CommandPacket(BasePacket):
 
 class ResponsePacket(BasePacket):
 
-    __slots__ = ( 'ok', 'msg', 'devices' )
+    __slots__ = ( 'ok', 'msg', 'data' )
 
-    def __init__(self, ok=True, msg=None, devices=None):
+    def __init__(self, ok=True, msg=None, data=None):
 
         self.ok = ok
         self.msg = msg
-        self.devices = devices
+        self.data = data
 
     def to_dict(self):
 
@@ -51,10 +51,17 @@ class ResponsePacket(BasePacket):
             ok = self.ok
         )
 
-        if self.devices is not None:
-            data["devices"] = self.devices
+        if self.data is not None:
+            data["data"] = self.data
         if self.msg is not None:
             data["msg"] = self.msg
 
         return data
 
+    @classmethod
+    def from_dict(self, data):
+        return ResponsePacket(
+            ok = data.get('ok', None),
+            data = data.get('data', None),
+            msg = data.get('msg', None)
+        )
